using SmallInjectorDemo.Interfaces;

namespace SmallInjectorDemo;

/// <summary>
/// A very useful class.
/// </summary>
public class ServiceConsumer
{
    private readonly IClock _clock;
    private readonly IServiceOne _service1;
    private readonly IServiceTwo _service2;
    private readonly string _id;

    /// <summary>
    /// Creates a new instance of <see cref="ServiceConsumer"/>.
    /// </summary>
    /// <param name="clock">The current clock</param>
    /// <param name="service1">injected service one.</param>
    /// <param name="service2">injected service two.</param>
    public ServiceConsumer(IClock clock, IServiceOne service1, IServiceTwo service2)
    {
        _clock = clock;
        _service1 = service1;
        _service2 = service2;
        _id = Guid.NewGuid().EncodeBase64String();
        Console.WriteLine(Helper.WriteMethodString(clock, _id));
    }

    /// <summary>
    /// Test the injected services.
    /// </summary>
    public void TestTheServices()
    {
        Console.WriteLine(ToString());
        Console.WriteLine(_service1.ToString());
        Console.WriteLine(_service2.ToString());
    }

    /// <inheritdoc />
    public override string ToString() => Helper.WriteMethodString(_clock, _id);
}
